@@ -74,10 +74,14 @@ public:
     // Whether to use the minimalistic UI or not. Defaults to false.
     static bool minimalMode();
 
+    static DrKonqi *instance();
+    QString m_glRenderer;
+    QString m_exceptionName;
+    QString m_exceptionWhat;
+
 private:
     DrKonqi();
     ~DrKonqi();
-    static DrKonqi *instance();
 
     SystemInformation *m_systemInformation = nullptr;
     AbstractDrKonqiBackend *m_backend = nullptr;
